<?php
/* --------------------------------------------------------------------------
   Lucianna Law – contact-form.php
   --------------------------------------------------------------------------
   - Turns off on-screen errors, logs everything to error_log.txt
   - Validates: first name, last name, phone, email, comment
   - Sends a plain-text email to the site owner
   - On success, JS-redirects to thank-you.html
------------------------------------------------------------------------------*/

// 1.  Runtime error handling --------------------------------------------------
ini_set('display_errors', 0);
ini_set('log_errors', 1);
ini_set('error_log', __DIR__ . '/error_log.txt');
error_reporting(E_ALL);

// 2.  Process POST only -------------------------------------------------------
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo '<strong>Error:</strong> Invalid request method.';
    error_log('Invalid request method: ' . $_SERVER['REQUEST_METHOD']);
    exit;
}

// 3.  Sanitise & validate input ----------------------------------------------
// Make sure the form’s inputs have *name* attributes matching these keys
$firstName = htmlspecialchars(trim($_POST['first_name'] ?? ''));
$lastName  = htmlspecialchars(trim($_POST['last_name']  ?? ''));
$phone     = htmlspecialchars(trim($_POST['phone']      ?? ''));
$email     = filter_var(trim($_POST['email'] ?? ''), FILTER_SANITIZE_EMAIL);
$comment   = htmlspecialchars(trim($_POST['comment']    ?? ''));

// Required fields
if (empty($firstName) || empty($lastName) || empty($phone) || empty($email)) {
    echo '<strong>Error:</strong> All fields except “Comment” are required.<br>';
    error_log('Validation failed: Missing required fields.');
    exit;
}

// Email format
if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
    echo '<strong>Error:</strong> Invalid email format.<br>';
    error_log("Validation failed: Invalid email format ($email).");
    exit;
}

// Phone format – digits, spaces, +, (), -
if (!preg_match('/^[0-9+\-\s()]+$/', $phone)) {
    echo '<strong>Error:</strong> Invalid phone number format.<br>';
    error_log("Validation failed: Invalid phone format ($phone).");
    exit;
}

// 4.  Prepare & send the message ---------------------------------------------
$to       = 'Nlucianna@msn.com,jose@compumaxllc.com,sarfarazwork2025@gmail.com';                   // Destination address
$subject  = 'New Consultation Request';           // Email subject
$body     = "First Name:  $firstName\n"
          . "Last  Name:  $lastName\n"
          . "Phone:       $phone\n"
          . "Email:       $email\n\n"
          . "Comment:\n$comment\n";

$fromEmail = 'Nlucianna@msn.com';                 // The “From:” address
$headers  = "From: Website Contact <$fromEmail>\r\n"
          . "Reply-To: $email\r\n"
          . "Content-Type: text/plain; charset=UTF-8\r\n";

// 5.  Send & respond ----------------------------------------------------------
if (mail($to, $subject, $body, $headers)) {
    // Using JS keeps HTML out of this PHP file
    echo '<!DOCTYPE html><html><head><title>Redirecting...</title></head><body>
            <script>window.location.href="thankyou.html";</script></body></html>';
    exit;
}

echo '<strong>Error:</strong> Failed to send email. Please try again later.';
error_log("Mail sending failed. Email: $email");
